(ansi-code color)Escape sequence for a color key, or for a vector of them ([:bold :cyan]). Empty string when colored output is off, so it stays safe to interpolate.
Escape sequence for a color key, or for a vector of them ([:bold :cyan]). Empty string when colored output is off, so it stays safe to interpolate.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |