(generate-step-fn {:keys [sentence sentence-keyword params]})return a string representing a spexec macro call corresponding to the sentence step
return a string representing a spexec macro call corresponding to the sentence step
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |